EXPORTS
	??0CVirtualCtorBase@VC@@QAE@XZ @ 1 NONAME ; VC::CVirtualCtorBase::CVirtualCtorBase(void)
	??1CVirtualCtorBase@VC@@UAE@XZ @ 2 NONAME ; VC::CVirtualCtorBase::~CVirtualCtorBase(void)
	?DeregisterInterface@CVirtualCtorBase@VC@@QAEXVTUid@@@Z @ 3 NONAME ; void VC::CVirtualCtorBase::DeregisterInterface(class TUid)
	?FindRawCtor@CVirtualCtorBase@VC@@IBEPAXABUSTypeId@Meta@@@Z @ 4 NONAME ; void * VC::CVirtualCtorBase::FindRawCtor(struct Meta::STypeId const &) const
	?IsInterfaceRegistered@CVirtualCtorBase@VC@@QBEHVTUid@@@Z @ 5 NONAME ; int VC::CVirtualCtorBase::IsInterfaceRegistered(class TUid) const
	?New@CVirtualCtorInPlace@VC@@QBEPAXABUSTypeId@Meta@@AAVTDes8@@@Z @ 6 NONAME ; void * VC::CVirtualCtorInPlace::New(struct Meta::STypeId const &, class TDes8 &) const
	?RegisterInterfaceL@CVirtualCtorBase@VC@@QAEXVTUid@@HPBUTImplementationProxy@@@Z @ 7 NONAME ; void VC::CVirtualCtorBase::RegisterInterfaceL(class TUid, int, struct TImplementationProxy const *)


